#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_firmware_ext(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def show_firmware_version_input_switchid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        input = ET.SubElement(show_firmware_version, "input")
        switchid = ET.SubElement(input, "switchid")
        switchid.text = kwargs.pop('switchid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_switchid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        switchid = ET.SubElement(show_firmware_version, "switchid")
        switchid.text = kwargs.pop('switchid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_os_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        os_name = ET.SubElement(show_firmware_version, "os-name")
        os_name.text = kwargs.pop('os_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_os_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        os_version = ET.SubElement(show_firmware_version, "os-version")
        os_version.text = kwargs.pop('os_version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_copy_right_info(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        copy_right_info = ET.SubElement(show_firmware_version, "copy-right-info")
        copy_right_info.text = kwargs.pop('copy_right_info')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_build_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        build_time = ET.SubElement(show_firmware_version, "build-time")
        build_time.text = kwargs.pop('build_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_firmware_full_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        firmware_full_version = ET.SubElement(show_firmware_version, "firmware-full-version")
        firmware_full_version.text = kwargs.pop('firmware_full_version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_control_processor_vendor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        control_processor_vendor = ET.SubElement(show_firmware_version, "control-processor-vendor")
        control_processor_vendor.text = kwargs.pop('control_processor_vendor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_control_processor_chipset(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        control_processor_chipset = ET.SubElement(show_firmware_version, "control-processor-chipset")
        control_processor_chipset.text = kwargs.pop('control_processor_chipset')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_control_processor_memory(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        control_processor_memory = ET.SubElement(show_firmware_version, "control-processor-memory")
        control_processor_memory.text = kwargs.pop('control_processor_memory')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_slot_no(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        slot_no = ET.SubElement(node_info, "slot-no")
        slot_no.text = kwargs.pop('slot_no')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_node_instance_no(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        node_instance_no = ET.SubElement(node_info, "node-instance-no")
        node_instance_no.text = kwargs.pop('node_instance_no')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_node_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        node_type = ET.SubElement(node_info, "node-type")
        node_type.text = kwargs.pop('node_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_is_active_cp(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        is_active_cp = ET.SubElement(node_info, "is-active-cp")
        is_active_cp.text = kwargs.pop('is_active_cp')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_firmware_version_info_application_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        firmware_version_info = ET.SubElement(node_info, "firmware-version-info")
        application_name = ET.SubElement(firmware_version_info, "application-name")
        application_name.text = kwargs.pop('application_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_firmware_version_info_primary_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        firmware_version_info = ET.SubElement(node_info, "firmware-version-info")
        primary_version = ET.SubElement(firmware_version_info, "primary-version")
        primary_version.text = kwargs.pop('primary_version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_firmware_version_info_secondary_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        firmware_version_info = ET.SubElement(node_info, "firmware-version-info")
        secondary_version = ET.SubElement(firmware_version_info, "secondary-version")
        secondary_version.text = kwargs.pop('secondary_version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_input_switchid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        input = ET.SubElement(show_firmware_version, "input")
        switchid = ET.SubElement(input, "switchid")
        switchid.text = kwargs.pop('switchid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_switchid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        switchid = ET.SubElement(show_firmware_version, "switchid")
        switchid.text = kwargs.pop('switchid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_os_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        os_name = ET.SubElement(show_firmware_version, "os-name")
        os_name.text = kwargs.pop('os_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_os_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        os_version = ET.SubElement(show_firmware_version, "os-version")
        os_version.text = kwargs.pop('os_version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_copy_right_info(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        copy_right_info = ET.SubElement(show_firmware_version, "copy-right-info")
        copy_right_info.text = kwargs.pop('copy_right_info')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_build_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        build_time = ET.SubElement(show_firmware_version, "build-time")
        build_time.text = kwargs.pop('build_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_firmware_full_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        firmware_full_version = ET.SubElement(show_firmware_version, "firmware-full-version")
        firmware_full_version.text = kwargs.pop('firmware_full_version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_control_processor_vendor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        control_processor_vendor = ET.SubElement(show_firmware_version, "control-processor-vendor")
        control_processor_vendor.text = kwargs.pop('control_processor_vendor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_control_processor_chipset(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        control_processor_chipset = ET.SubElement(show_firmware_version, "control-processor-chipset")
        control_processor_chipset.text = kwargs.pop('control_processor_chipset')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_control_processor_memory(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        control_processor_memory = ET.SubElement(show_firmware_version, "control-processor-memory")
        control_processor_memory.text = kwargs.pop('control_processor_memory')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_slot_no(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        slot_no = ET.SubElement(node_info, "slot-no")
        slot_no.text = kwargs.pop('slot_no')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_node_instance_no(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        node_instance_no = ET.SubElement(node_info, "node-instance-no")
        node_instance_no.text = kwargs.pop('node_instance_no')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_node_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        node_type = ET.SubElement(node_info, "node-type")
        node_type.text = kwargs.pop('node_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_is_active_cp(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        is_active_cp = ET.SubElement(node_info, "is-active-cp")
        is_active_cp.text = kwargs.pop('is_active_cp')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_firmware_version_info_application_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        firmware_version_info = ET.SubElement(node_info, "firmware-version-info")
        application_name = ET.SubElement(firmware_version_info, "application-name")
        application_name.text = kwargs.pop('application_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_firmware_version_info_primary_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        firmware_version_info = ET.SubElement(node_info, "firmware-version-info")
        primary_version = ET.SubElement(firmware_version_info, "primary-version")
        primary_version.text = kwargs.pop('primary_version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_firmware_version_output_show_firmware_version_node_info_firmware_version_info_secondary_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_firmware_version = ET.Element("show_firmware_version")
        config = show_firmware_version
        output = ET.SubElement(show_firmware_version, "output")
        show_firmware_version = ET.SubElement(output, "show-firmware-version")
        node_info = ET.SubElement(show_firmware_version, "node-info")
        firmware_version_info = ET.SubElement(node_info, "firmware-version-info")
        secondary_version = ET.SubElement(firmware_version_info, "secondary-version")
        secondary_version.text = kwargs.pop('secondary_version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""


import unittest
import xml.etree.ElementTree as ET
import pynos.versions.base.interface as interface
from pynos.exceptions import InvalidVlanId
import pynos.utilities


class TestInterface(unittest.TestCase):

    """
    Interface unit tests. Compare expected XML to generated XML.
    """

    def setUp(self):
        self.interface = interface.Interface(pynos.utilities.return_xml)
        self.namespace = 'urn:brocade.com:mgmt:brocade-interface'
        self.phys_int_type = 'gigabitethernet'
        self.phys_vlan_type = 'vlan'
        self.phys_port_channel_type = 'port-channel'
        self.phys_name = '1/0/0'
        self.port_channel_name = '20'
        self.vlan_id = '40'
        self.sec_vlan = '50'
        self.ipv4_config_namespace = 'urn:brocade.com:mgmt:brocade-ip-config'
        self.ipv4_address = '20.10.10.1/24'
        self.ipv6_address = 'fc00:1:3:1ad3:0:0:23:a/64'
        self.ipv6_config_namespace = 'urn:brocade.com:mgmt:brocade-ipv6-config'

    def raise_exception(self, *args, **kwargs):
        raise Exception()

    def raise_attribute_error(self, *args, **kwargs):
        raise AttributeError()

    def test_description(self):
        expected = '<config>'\
                   '<interface xmlns="{}"><gigabitethernet>'\
                   '<name>1/0/0</name>'\
                   '<description>Hodor</description>'\
                   '</gigabitethernet></interface>'\
                   '</config>'.format(self.namespace)
        description = 'Hodor'
        result = self.interface.description(int_type=self.phys_int_type,
                                            name=self.phys_name,
                                            desc=description)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_description_exception(self):
        with self.assertRaises(KeyError):
            self.interface.description(int_type=self.phys_int_type,
                                       desc='Hodor')

    def test_private_vlan_type(self):
        expected = '<config>'\
                   '<interface-vlan xmlns="{}"><interface>'\
                   '<vlan><name>40</name><private-vlan>'\
                   '<pvlan-type-leaf>isolated</pvlan-type-leaf>'\
                   '</private-vlan></vlan></interface></interface-vlan>'\
                   '</config>'.format(self.namespace)
        result = self.interface.private_vlan_type(name=self.vlan_id,
                                                  pvlan_type='isolated')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_private_vlan_type_exception(self):
        with self.assertRaises(KeyError):
            self.interface.private_vlan_type(name=self.vlan_id)

    def test_vlan_pvlan_association_add(self):
        expected = '<config><interface-vlan xmlns="{}"><interface><vlan>'\
                   '<name>{}</name><private-vlan><association>'\
                   '<sec-assoc-add>{}</sec-assoc-add></association>'\
                   '</private-vlan></vlan></interface></interface-vlan>'\
                   '</config>'.format(self.namespace,
                                      self.vlan_id,
                                      self.sec_vlan)
        interface = self.interface
        result = interface.vlan_pvlan_association_add(name=self.vlan_id,
                                                      sec_vlan=self.sec_vlan)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_vlan_pvlan_association_add_exception(self):
        with self.assertRaises(KeyError):
            self.interface.vlan_pvlan_association_add(name=self.vlan_id)

    def test_pvlan_host_association(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><private-vlan><host-association>'\
                   '<host-pri-pvlan>{3}</host-pri-pvlan>'\
                   '<host-sec-pvlan>{4}</host-sec-pvlan></host-association>'\
                   '</private-vlan></switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name, self.vlan_id,
                                      self.sec_vlan)
        interface = self.interface
        result = interface.pvlan_host_association(int_type=self.phys_int_type,
                                                  name=self.phys_name,
                                                  pri_vlan=self.vlan_id,
                                                  sec_vlan=self.sec_vlan)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_pvlan_host_association_exception(self):
        with self.assertRaises(KeyError):
            self.interface.pvlan_host_association(name=self.vlan_id)

    def test_admin_state_disabled(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<shutdown /></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.admin_state(int_type=self.phys_int_type,
                                            name=self.phys_name,
                                            enabled=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_admin_state_enabled(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<shutdown operation="delete" /></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.admin_state(int_type=self.phys_int_type,
                                            name=self.phys_name,
                                            enabled=True)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_admin_state_exception(self):
        with self.assertRaises(KeyError):
            self.interface.admin_state(name=self.phys_name)

    def test_trunk_allowed_vlan_add(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><trunk><allowed><vlan><add>{3}</add></vlan>'\
                   '</allowed></trunk></switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name, self.vlan_id)
        result = self.interface.trunk_allowed_vlan(int_type=self.phys_int_type,
                                                   name=self.phys_name,
                                                   vlan=self.vlan_id,
                                                   action='add')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_trunk_allowed_vlan_remove(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><trunk><allowed><vlan><remove>{3}</remove>'\
                   '</vlan></allowed></trunk></switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name, self.vlan_id)
        result = self.interface.trunk_allowed_vlan(int_type=self.phys_int_type,
                                                   name=self.phys_name,
                                                   vlan=self.vlan_id,
                                                   action='remove')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_trunk_allowed_vlan_all(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><trunk><allowed><vlan><all /></vlan>'\
                   '</allowed></trunk></switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.trunk_allowed_vlan(int_type=self.phys_int_type,
                                                   name=self.phys_name,
                                                   vlan=self.vlan_id,
                                                   action='all')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_trunk_allowed_vlan_none(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><trunk><allowed><vlan><none /></vlan>'\
                   '</allowed></trunk></switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.trunk_allowed_vlan(int_type=self.phys_int_type,
                                                   name=self.phys_name,
                                                   vlan=self.vlan_id,
                                                   action='none')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_trunk_allowed_vlan_add_ctag(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><trunk><trunk-vlan-classification><allowed>'\
                   '<vlan><add><trunk-vlan-id>{3}</trunk-vlan-id>'\
                   '<trunk-ctag-range>{4}</trunk-ctag-range></add></vlan>'\
                   '</allowed></trunk-vlan-classification></trunk>'\
                   '</switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name, self.vlan_id,
                                      self.sec_vlan)
        result = self.interface.trunk_allowed_vlan(int_type=self.phys_int_type,
                                                   name=self.phys_name,
                                                   vlan=self.vlan_id,
                                                   ctag=self.sec_vlan,
                                                   action='add')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_trunk_allowed_vlan_remove_ctag(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><trunk><trunk-vlan-classification><allowed>'\
                   '<vlan><remove><trunk-vlan-id>{3}</trunk-vlan-id>'\
                   '<trunk-ctag-range>{4}</trunk-ctag-range></remove></vlan>'\
                   '</allowed></trunk-vlan-classification></trunk>'\
                   '</switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name, self.vlan_id,
                                      self.sec_vlan)
        result = self.interface.trunk_allowed_vlan(int_type=self.phys_int_type,
                                                   name=self.phys_name,
                                                   vlan=self.vlan_id,
                                                   ctag=self.sec_vlan,
                                                   action='remove')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_trunk_allowed_vlan_exception(self):
        with self.assertRaises(KeyError):
            self.interface.trunk_allowed_vlan(name=self.phys_name)

    def test_mtu(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<mtu>1666</mtu></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.mtu(int_type=self.phys_int_type,
                                    name=self.phys_name,
                                    mtu='1666')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_mtu_exception(self):
        with self.assertRaises(KeyError):
            self.interface.mtu(name=self.phys_name)

    def test_spanning_tree_state_phys_enabled(self):
        stp_namespace = 'urn:brocade.com:mgmt:brocade-xstp'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<spanning-tree xmlns="{3}">'\
                   '<shutdown operation="delete" /></spanning-tree></{1}>'\
                   '</interface></config>'.format(self.namespace,
                                                  self.phys_int_type,
                                                  self.phys_name,
                                                  stp_namespace)
        interface = self.interface
        result = interface.spanning_tree_state(int_type=self.phys_int_type,
                                               name=self.phys_name,
                                               enabled=True)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_spanning_tree_state_phys_disabled(self):
        stp_namespace = 'urn:brocade.com:mgmt:brocade-xstp'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<spanning-tree xmlns="{3}"><shutdown /></spanning-tree>'\
                   '</{1}></interface></config>'.format(self.namespace,
                                                        self.phys_int_type,
                                                        self.phys_name,
                                                        stp_namespace)
        interface = self.interface
        result = interface.spanning_tree_state(int_type=self.phys_int_type,
                                               name=self.phys_name,
                                               enabled=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_spanning_tree_state_vlan_enabled(self):
        stp_namespace = 'urn:brocade.com:mgmt:brocade-xstp'
        expected = '<config><interface-vlan xmlns="{0}"><interface><vlan>'\
                   '<name>{1}</name><spanning-tree xmlns="{2}">'\
                   '<stp-shutdown operation="delete" /></spanning-tree>'\
                   '</vlan></interface></interface-vlan>'\
                   '</config>'.format(self.namespace, self.vlan_id,
                                      stp_namespace)
        interface = self.interface
        result = interface.spanning_tree_state(int_type='vlan',
                                               name=self.vlan_id,
                                               enabled=True)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_spanning_tree_state_vlan_disabled(self):
        stp_namespace = 'urn:brocade.com:mgmt:brocade-xstp'
        expected = '<config><interface-vlan xmlns="{0}"><interface><vlan>'\
                   '<name>{1}</name><spanning-tree xmlns="{2}">'\
                   '<stp-shutdown /></spanning-tree>'\
                   '</vlan></interface></interface-vlan>'\
                   '</config>'.format(self.namespace, self.vlan_id,
                                      stp_namespace)
        interface = self.interface
        result = interface.spanning_tree_state(int_type='vlan',
                                               name=self.vlan_id,
                                               enabled=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_spanning_tree_state_port_channel_enabled(self):
        stp_namespace = 'urn:brocade.com:mgmt:brocade-xstp'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<spanning-tree xmlns="{3}">'\
                   '<shutdown operation="delete" /></spanning-tree></{1}>'\
                   '</interface></config>'.format(self.namespace,
                                                  self.phys_port_channel_type,
                                                  self.port_channel_name,
                                                  stp_namespace)
        interface = self.interface
        result = interface.spanning_tree_state(
            int_type='port_channel', name=self.port_channel_name,
            enabled=True)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_spanning_tree_state_port_channel_disabled(self):
        stp_namespace = 'urn:brocade.com:mgmt:brocade-xstp'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<spanning-tree xmlns="{3}"><shutdown /></spanning-tree>'\
                   '</{1}></interface>'\
                   '</config>'.format(self.namespace,
                                      self.phys_port_channel_type,
                                      self.port_channel_name, stp_namespace)
        interface = self.interface
        result = interface.spanning_tree_state(
            int_type='port_channel',
            name=self.port_channel_name,
            enabled=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_spanning_tree_state_exception(self):
        with self.assertRaises(KeyError):
            self.interface.spanning_tree_state(name=self.phys_name)

    def test_private_vlan_mode(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><mode><private-vlan><host /></private-vlan>'\
                   '</mode></switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.private_vlan_mode(int_type=self.phys_int_type,
                                                  name=self.phys_name,
                                                  mode='host')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_private_vlan_mode_exception(self):
        with self.assertRaises(KeyError):
            self.interface.private_vlan_mode(name=self.vlan_id)

    def test_vrrp_vip_ipv4(self):
        namespace = 'urn:brocade.com:mgmt:brocade-vrrp'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<vrrp xmlns="{3}"><vrid>1</vrid><version>3</version>'\
                   '<virtual-ip><virtual-ipaddr>10.10.10.10</virtual-ipaddr>'\
                   '</virtual-ip></vrrp></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name, namespace)

        result = self.interface.vrrp_vip(int_type=self.phys_int_type, vrid='1',
                                         name=self.phys_name,
                                         vip='10.10.10.10/24')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_vrrp_vip_ipv6(self):
        namespace = 'urn:brocade.com:mgmt:brocade-vrrpv3'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<ipv6><vrrpv3-group xmlns="{3}"><vrid>1</vrid>'\
                   '<virtual-ip><virtual-ipaddr>2001::1</virtual-ipaddr>'\
                   '</virtual-ip></vrrpv3-group></ipv6></gigabitethernet>'\
                   '</interface></config>'.format(self.namespace,
                                                  self.phys_int_type,
                                                  self.phys_name,
                                                  namespace)

        result = self.interface.vrrp_vip(int_type=self.phys_int_type, vrid='1',
                                         name=self.phys_name, vip='2001::1/64')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_vrrp_vip_exception(self):
        with self.assertRaises(KeyError):
            self.interface.vrrp_vip()

    def test_vrrp_priority_ipv4(self):
        namespace = 'urn:brocade.com:mgmt:brocade-vrrp'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<vrrp xmlns="{3}"><vrid>1</vrid><version>3</version>'\
                   '<priority>50</priority></vrrp></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name, namespace)
        result = self.interface.vrrp_priority(int_type=self.phys_int_type,
                                              name=self.phys_name,
                                              priority='50', vrid='1',
                                              ip_version='4')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_vrrp_priority_ipv6(self):
        namespace = 'urn:brocade.com:mgmt:brocade-vrrpv3'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<ipv6><vrrpv3-group xmlns="{3}"><vrid>1</vrid>'\
                   '<priority>50</priority></vrrpv3-group></ipv6></{1}>'\
                   '</interface></config>'.format(self.namespace,
                                                  self.phys_int_type,
                                                  self.phys_name, namespace)
        result = self.interface.vrrp_priority(int_type=self.phys_int_type,
                                              name=self.phys_name,
                                              priority='50', vrid='1',
                                              ip_version='6')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_vrrp_priority_exception(self):
        with self.assertRaises(KeyError):
            self.interface.vrrp_priority()

    def test_proxy_arp_enabled(self):
        namespace = 'urn:brocade.com:mgmt:brocade-ip-config'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<ip><ip-config xmlns="{3}"><proxy-arp /></ip-config></ip>'\
                   '</{1}></interface></config>'.format(self.namespace,
                                                        self.phys_int_type,
                                                        self.phys_name,
                                                        namespace)
        result = self.interface.proxy_arp(int_type=self.phys_int_type,
                                          name=self.phys_name, enabled=True)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_proxy_arp_disabled(self):
        namespace = 'urn:brocade.com:mgmt:brocade-ip-config'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<ip><ip-config xmlns="{3}">'\
                   '<proxy-arp operation="delete" /></ip-config></ip>'\
                   '</{1}></interface></config>'.format(self.namespace,
                                                        self.phys_int_type,
                                                        self.phys_name,
                                                        namespace)
        result = self.interface.proxy_arp(int_type=self.phys_int_type,
                                          name=self.phys_name, enabled=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_proxy_arp_exception(self):
        with self.assertRaises(KeyError):
            self.interface.proxy_arp()

    def test_lacp_timeout_short(self):
        namespace = 'urn:brocade.com:mgmt:brocade-lacp'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<lacp xmlns="{3}"><timeout>short</timeout></lacp></{1}>'\
                   '</interface></config>'.format(self.namespace,
                                                  self.phys_int_type,
                                                  self.phys_name, namespace)
        result = self.interface.lacp_timeout(int_type=self.phys_int_type,
                                             name=self.phys_name,
                                             timeout='short')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_lacp_timeout_long(self):
        namespace = 'urn:brocade.com:mgmt:brocade-lacp'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<lacp xmlns="{3}"><timeout>long</timeout></lacp></{1}>'\
                   '</interface></config>'.format(self.namespace,
                                                  self.phys_int_type,
                                                  self.phys_name, namespace)
        result = self.interface.lacp_timeout(int_type=self.phys_int_type,
                                             name=self.phys_name,
                                             timeout='long')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_lacp_timeout_exception(self):
        with self.assertRaises(KeyError):
            self.interface.lacp_timeout()

    def test_transport_service(self):
        expected = '<config><interface-vlan xmlns="{0}"><interface><vlan>'\
                   '<name>{1}</name><transport-service>1</transport-service>'\
                   '</vlan></interface></interface-vlan>'\
                   '</config>'.format(self.namespace, self.vlan_id)
        result = self.interface.transport_service(vlan=self.vlan_id,
                                                  service_id='1')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_transport_service_exception(self):
        with self.assertRaises(KeyError):
            self.interface.transport_service()

    def test_port_channel_minimum_links(self):
        expected = '<config><interface xmlns="{0}"><port-channel><name>'\
                   '3</name><minimum-links>2</minimum-links></port-channel>'\
                   '</interface></config>'.format(self.namespace)
        result = self.interface.port_channel_minimum_links(name='3',
                                                           minimum_links='2')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_port_channel_minimum_links_exception(self):
        with self.assertRaises(KeyError):
            self.interface.port_channel_minimum_links()

    def test_fabric_isl_enabled(self):
        namespace = 'urn:brocade.com:mgmt:brocade-fcoe'
        expected = '<config><interface xmlns="{0}"><tengigabitethernet><name>'\
                   '{1}</name><fabric xmlns="{2}"><fabric-isl>'\
                   '<fabric-isl-enable /></fabric-isl></fabric>'\
                   '</tengigabitethernet></interface>'\
                   '</config>'.format(self.namespace, self.phys_name,
                                      namespace)
        result = self.interface.fabric_isl(int_type='tengigabitethernet',
                                           name=self.phys_name)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_fabric_isl_disabled(self):
        namespace = 'urn:brocade.com:mgmt:brocade-fcoe'
        expected = '<config><interface xmlns="{0}"><tengigabitethernet><name>'\
                   '{1}</name><fabric xmlns="{2}">'\
                   '<fabric-isl operation="delete"><fabric-isl-enable />'\
                   '</fabric-isl></fabric></tengigabitethernet></interface>'\
                   '</config>'.format(self.namespace, self.phys_name,
                                      namespace)
        result = self.interface.fabric_isl(int_type='tengigabitethernet',
                                           name=self.phys_name, enabled=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_fabric_isl_exception(self):
        with self.assertRaises(KeyError):
            self.interface.fabric_isl()

    def test_fabric_trunk_enabled(self):
        namespace = 'urn:brocade.com:mgmt:brocade-fcoe'
        expected = '<config><interface xmlns="{0}"><tengigabitethernet><name>'\
                   '{1}</name><fabric xmlns="{2}"><fabric-trunk>'\
                   '<fabric-trunk-enable /></fabric-trunk></fabric>'\
                   '</tengigabitethernet></interface>'\
                   '</config>'.format(self.namespace, self.phys_name,
                                      namespace)
        result = self.interface.fabric_trunk(int_type='tengigabitethernet',
                                             name=self.phys_name)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_fabric_trunk_disabled(self):
        namespace = 'urn:brocade.com:mgmt:brocade-fcoe'
        expected = '<config><interface xmlns="{0}"><tengigabitethernet><name>'\
                   '{1}</name><fabric xmlns="{2}">'\
                   '<fabric-trunk operation="delete"><fabric-trunk-enable />'\
                   '</fabric-trunk></fabric></tengigabitethernet></interface>'\
                   '</config>'.format(self.namespace, self.phys_name,
                                      namespace)
        result = self.interface.fabric_trunk(int_type='tengigabitethernet',
                                             name=self.phys_name,
                                             enabled=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_fabric_trunk_exception(self):
        with self.assertRaises(KeyError):
            self.interface.fabric_trunk()

    def test_channel_group_brocade(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<channel-group><mode>active</mode><port-int>5</port-int>'\
                   '<type>brocade</type></channel-group></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.channel_group(int_type=self.phys_int_type,
                                              name=self.phys_name,
                                              mode='active', port_int='5',
                                              channel_type='brocade')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_channel_group_standard(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<channel-group><mode>active</mode><port-int>5</port-int>'\
                   '<type>standard</type></channel-group></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.channel_group(int_type=self.phys_int_type,
                                              name=self.phys_name,
                                              mode='active', port_int='5',
                                              channel_type='standard')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_channel_group_exception(self):
        with self.assertRaises(KeyError):
            self.interface.channel_group()

    def test_port_channel_vlag_ignore_split_enabled(self):
        expected = '<config><interface xmlns="{0}"><port-channel>'\
                   '<name>5</name><vlag><ignore-split /></vlag>'\
                   '</port-channel></interface>'\
                   '</config>'.format(self.namespace)
        result = self.interface.port_channel_vlag_ignore_split(name='5',
                                                               enabled=True)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_port_channel_vlag_ignore_split_disabled(self):
        expected = '<config><interface xmlns="{0}"><port-channel>'\
                   '<name>5</name><vlag><ignore-split operation="delete" />'\
                   '</vlag></port-channel></interface>'\
                   '</config>'.format(self.namespace)
        result = self.interface.port_channel_vlag_ignore_split(name='5',
                                                               enabled=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_port_channel_vlag_ignore_split_exception(self):
        with self.assertRaises(KeyError):
            self.interface.port_channel_vlag_ignore_split()

    def test_tag_native_vlan_enabled(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><trunk><tag><native-vlan /></tag></trunk>'\
                   '</switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.tag_native_vlan(int_type=self.phys_int_type,
                                                name=self.phys_name)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_tag_native_vlan_disabled(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><trunk><tag>'\
                   '<native-vlan operation="delete" /></tag></trunk>'\
                   '</switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.tag_native_vlan(int_type=self.phys_int_type,
                                                name=self.phys_name,
                                                enabled=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_tag_native_vlan_exception(self):
        with self.assertRaises(KeyError):
            self.interface.tag_native_vlan()

    def test_v6_nd_suppress_ra(self):
        ra_namespace = 'urn:brocade.com:mgmt:brocade-ipv6-nd-ra'
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<ipv6><ipv6-nd-ra xmlns="{3}"><ipv6-intf-cmds><nd>'\
                   '<suppress-ra><suppress-ra-all /></suppress-ra></nd>'\
                   '</ipv6-intf-cmds></ipv6-nd-ra></ipv6></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name, ra_namespace)
        result = self.interface.v6_nd_suppress_ra(int_type=self.phys_int_type,
                                                  name=self.phys_name)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_v6_nd_suppress_ra_interface_ve(self):
        rbridge_namespace = 'urn:brocade.com:mgmt:brocade-rbridge'
        ipv6_namespace = 'urn:brocade.com:mgmt:brocade-ipv6-config'
        ra_namespace = 'urn:brocade.com:mgmt:brocade-ipv6-nd-ra'
        expected = '<config><rbridge-id xmlns="{0}"><rbridge-id>1'\
                   '</rbridge-id><interface xmlns="{1}"><ve><name>7</name>'\
                   '<ipv6 xmlns="{2}"><ipv6-nd-ra xmlns="{3}">'\
                   '<ipv6-intf-cmds><nd><suppress-ra><suppress-ra-all />'\
                   '</suppress-ra></nd></ipv6-intf-cmds></ipv6-nd-ra></ipv6>'\
                   '</ve></interface></rbridge-id>'\
                   '</config>'.format(rbridge_namespace, self.namespace,
                                      ipv6_namespace, ra_namespace)
        result = self.interface.v6_nd_suppress_ra(int_type='ve', name='7')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_v6_nd_suppress_ra_exception(self):
        with self.assertRaises(KeyError):
            self.interface.v6_nd_suppress_ra()

    def test_trunk_mode(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><mode><vlan-mode>trunk</vlan-mode></mode>'\
                   '</switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.trunk_mode(int_type=self.phys_int_type,
                                           name=self.phys_name, mode='trunk')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_trunk_mode_exception(self):
        with self.assertRaises(KeyError):
            self.interface.trunk_mode()

    def test_switchport_pvlan_mapping(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<switchport><private-vlan><mapping><promis-pri-pvlan>'\
                   '{3}</promis-pri-pvlan><promis-sec-pvlan-range>{4}'\
                   '</promis-sec-pvlan-range></mapping></private-vlan>'\
                   '</switchport></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name, self.vlan_id,
                                      self.sec_vlan)
        intf = self.interface
        result = intf.switchport_pvlan_mapping(int_type=self.phys_int_type,
                                               name=self.phys_name,
                                               pri_vlan=self.vlan_id,
                                               sec_vlan=self.sec_vlan)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_switchport_pvlan_mapping_exception(self):
        with self.assertRaises(KeyError):
            self.interface.switchport_pvlan_mapping()

    def test_ip_address_exception(self):
        with self.assertRaises(KeyError):
            self.interface.ip_address(name=self.phys_name)

    def test_ipv4_address_add(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<ip><ip-config xmlns="{3}"><address><address>{4}'\
                   '</address></address></ip-config></ip></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name,
                                      self.ipv4_config_namespace,
                                      self.ipv4_address)
        result = self.interface.ip_address(int_type=self.phys_int_type,
                                           name=self.phys_name,
                                           ip_addr=self.ipv4_address,
                                           delete=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_ipv4_address_delete(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<ip><ip-config xmlns="{3}"><address operation="delete">'\
                   '<address>{4}</address></address></ip-config></ip></{1}>'\
                   '</interface></config>'.format(self.namespace,
                                                  self.phys_int_type,
                                                  self.phys_name,
                                                  self.ipv4_config_namespace,
                                                  self.ipv4_address)
        result = self.interface.ip_address(int_type=self.phys_int_type,
                                           name=self.phys_name,
                                           ip_addr=self.ipv4_address,
                                           delete=True)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_ipv6_address_add(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<ipv6><ipv6-config xmlns="{3}"><address><ipv6-address>'\
                   '<address>{4}</address></ipv6-address></address>'\
                   '</ipv6-config></ipv6></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name,
                                      self.ipv6_config_namespace,
                                      self.ipv6_address)
        result = self.interface.ip_address(int_type=self.phys_int_type,
                                           name=self.phys_name,
                                           ip_addr=self.ipv6_address,
                                           delete=False)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_ipv6_address_delete(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<ipv6><ipv6-config xmlns="{3}"><address '\
                   'operation="delete"><ipv6-address><address>{4}</address>'\
                   '</ipv6-address></address></ipv6-config></ipv6></{1}>'\
                   '</interface></config>'.format(self.namespace,
                                                  self.phys_int_type,
                                                  self.phys_name,
                                                  self.ipv6_config_namespace,
                                                  self.ipv6_address)
        result = self.interface.ip_address(int_type=self.phys_int_type,
                                           name=self.phys_name,
                                           ip_addr=self.ipv6_address,
                                           delete=True)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_ip_address_int_type_exception(self):
        with self.assertRaises(ValueError):
            self.interface.ip_address(int_type='junk',
                                      name=self.phys_name,
                                      ip_addr=self.ipv6_address,
                                      delete=False)

    def test_ip_address_interface_name_exception(self):
        with self.assertRaises(ValueError):
            self.interface.ip_address(int_type=self.phys_int_type,
                                      name='junk',
                                      ip_addr=self.ipv6_address,
                                      delete=False)

    def test_remove_port_channel_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.remove_port_channel(port_int='2/0/3')

    def test_ip_address_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.ip_address(int_type='port_channel', name='225/0/20',
                                      ip_addr='10.0.0.1/30')

    def test_ip_address_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.ip_address(int_type='tengigabitethernet',
                                      name='225/0', ip_addr='10.0.0.1/30')

    def test_description_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.description(int_type='port-channel', name='5',
                                       desc='hodor')

    def test_description_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.description(int_type='gigabitethernet', name='5/0',
                                       desc='hodor')

    def test_description_vlan_name_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.description(int_type='vlan', name='9000',
                                       desc='hodor')

    def test_description_vlan(self):
        desc = 'Hodor'
        expected = '<config><interface-vlan xmlns="{0}"><interface><vlan>'\
                   '<name>{1}</name><description>{2}</description></vlan>'\
                   '</interface></interface-vlan>'\
                   '</config>'.format(self.namespace, self.vlan_id, desc)
        result = self.interface.description(int_type='vlan', name=self.vlan_id,
                                            desc=desc)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_private_vlan_type_vlan_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.private_vlan_type(name='9000',
                                             pvlan_type='primary')

    def test_private_vlan_type_pvlan_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.private_vlan_type(name='5', pvlan_type='hodor')

    def test_vlan_pvlan_association_add_vlan_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.vlan_pvlan_association_add(name='9000',
                                                      sec_vlan='5')

    def test_vlan_pvlan_association_add_sec_vlan_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.vlan_pvlan_association_add(name='5',
                                                      sec_vlan='9000')

    def test_add_vlan_int_exception(self):
        self.interface._callback = self.raise_exception
        expected = False
        result = self.interface.add_vlan_int(self.vlan_id)
        self.assertEquals(expected, result)

    def test_del_vlan_int_exception(self):
        self.interface._callback = self.raise_exception
        expected = False
        result = self.interface.del_vlan_int(self.vlan_id)
        self.assertEquals(expected, result)

    def test_enable_switchport_exception(self):
        self.interface._callback = self.raise_exception
        expected = False
        result = self.interface.enable_switchport(self.phys_int_type,
                                                  self.phys_name)
        self.assertEquals(expected, result)

    def test_disable_switchport_exception(self):
        self.interface._callback = self.raise_exception
        expected = False
        result = self.interface.disable_switchport(self.phys_int_type,
                                                   self.phys_name)
        self.assertEquals(expected, result)

    def test_access_vlan_exception(self):
        self.interface._callback = self.raise_exception
        expected = False
        result = self.interface.access_vlan(self.phys_int_type, self.phys_name,
                                            self.vlan_id)
        self.assertEquals(expected, result)

    def test_del_access_vlan_exception(self):
        self.interface._callback = self.raise_exception
        expected = False
        result = self.interface.del_access_vlan(self.phys_int_type,
                                                self.phys_name,
                                                self.vlan_id)
        self.assertEquals(expected, result)

    def test_set_ip_exception(self):
        self.interface._callback = self.raise_exception
        expected = False
        result = self.interface.set_ip(self.phys_int_type, self.phys_name,
                                       self.ipv4_address)
        self.assertEquals(expected, result)

    def test_del_ip_exception(self):
        self.interface._callback = self.raise_exception
        expected = False
        result = self.interface.del_ip(self.phys_int_type, self.phys_name,
                                       self.ipv4_address)
        self.assertEquals(expected, result)

    def test_ip_address_attribute_error(self):
        self.interface._callback = self.raise_attribute_error
        expected = None
        result = self.interface.ip_address(int_type=self.phys_int_type,
                                           name=self.phys_name,
                                           ip_addr=self.ipv4_address)
        self.assertEquals(expected, result)

    def test_admin_state_attribute_error(self):
        self.interface._callback = self.raise_attribute_error
        expected = None
        result = self.interface.admin_state(int_type=self.phys_int_type,
                                            name=self.phys_name,
                                            enabled=True)
        self.assertEquals(expected, result)

    def test_spanning_tree_state_attribute_error(self):
        self.interface._callback = self.raise_attribute_error
        expected = None
        int_type = self.phys_int_type
        result = self.interface.spanning_tree_state(int_type=int_type,
                                                    name=self.phys_name,
                                                    enabled=True)
        self.assertEquals(expected, result)

    def test_tag_native_vlan_attribute_error(self):
        self.interface._callback = self.raise_attribute_error
        expected = None
        result = self.interface.tag_native_vlan(int_type=self.phys_int_type,
                                                name=self.phys_name,
                                                mode='trunk',
                                                enabled=True)
        self.assertEquals(expected, result)

    def test_proxy_arp_attribute_error(self):
        self.interface._callback = self.raise_attribute_error
        expected = None
        result = self.interface.proxy_arp(int_type=self.phys_int_type,
                                          name=self.phys_name,
                                          enabled=True)
        self.assertEquals(expected, result)

    def test_pvlan_host_association_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.pvlan_host_association(int_type='port-channel',
                                                  name='5',
                                                  pri_vlan=self.vlan_id,
                                                  sec_vlan=self.sec_vlan)

    def test_pvlan_host_association_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.pvlan_host_association(int_type='port_channel',
                                                  name='2/0',
                                                  pri_vlan=self.vlan_id,
                                                  sec_vlan=self.sec_vlan)

    def test_pvlan_host_association_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.pvlan_host_association(int_type='gigabitethernet',
                                                  name='2/0',
                                                  pri_vlan=self.vlan_id,
                                                  sec_vlan=self.sec_vlan)

    def test_pvlan_host_association_pri_vlan_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.pvlan_host_association(int_type='gigabitethernet',
                                                  name='2/0/1',
                                                  pri_vlan='9000',
                                                  sec_vlan=self.sec_vlan)

    def test_pvlan_host_association_sec_vlan_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.pvlan_host_association(int_type='gigabitethernet',
                                                  name='2/0/1',
                                                  pri_vlan=self.vlan_id,
                                                  sec_vlan='9000')

    def test_admin_state_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.admin_state(int_type='port-channel', name='5',
                                       enabled=True)

    def test_admin_state_bool_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.admin_state(int_type='port_channel', name='5',
                                       enabled='True')

    def test_admin_state_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.admin_state(int_type=self.phys_int_type, name='5',
                                       enabled='True')

    def test_admin_state_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.admin_state(int_type='port_channel', name='225/0/0',
                                       enabled='True')

    def test_trunk_allowed_vlan_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.trunk_allowed_vlan(int_type='port-channel',
                                              name='5', action='add',
                                              vlan=self.vlan_id,
                                              ctag=self.sec_vlan)

    def test_trunk_allowed_vlan_action_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.trunk_allowed_vlan(int_type='port_channel',
                                              name='5', action='hodor',
                                              vlan=self.vlan_id,
                                              ctag=self.sec_vlan)

    def test_trunk_allowed_vlan_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.trunk_allowed_vlan(int_type=self.phys_int_type,
                                              name='5/0', action='add',
                                              vlan=self.vlan_id,
                                              ctag=self.sec_vlan)

    def test_trunk_allowed_vlan_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.trunk_allowed_vlan(int_type='port_channel',
                                              name='2/0', action='add',
                                              vlan=self.vlan_id,
                                              ctag=self.sec_vlan)

    def test_trunk_allowed_vlan_ctag_missing_vlan_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.trunk_allowed_vlan(int_type='port_channel',
                                              name='2', action='add',
                                              ctag=self.sec_vlan)

    def test_trunk_allowed_vlan_ctag_action_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.trunk_allowed_vlan(int_type='port_channel',
                                              name='2/0', action='all',
                                              vlan=self.vlan_id,
                                              ctag=self.sec_vlan)

    def test_private_vlan_mode_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.private_vlan_mode(int_type='port-channel',
                                             name='2', mode='host')

    def test_private_vlan_mode_mode_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.private_vlan_mode(int_type='port_channel',
                                             name='2', mode='hodor')

    def test_private_vlan_mode_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.private_vlan_mode(int_type=self.phys_int_type,
                                             name='2/0', mode='host')

    def test_private_vlan_mode_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.private_vlan_mode(int_type='port_channel',
                                             name='3/0', mode='host')

    def test_spanning_tree_state_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.spanning_tree_state(int_type='port-channel',
                                               name='3', enabled=True)

    def test_spanning_tree_state_bool_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.spanning_tree_state(int_type='port_channel',
                                               name='3', enabled='hodor')

    def test_spanning_tree_state_vlan_name_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.spanning_tree_state(int_type='vlan',
                                               name='9000', enabled=True)

    def test_spanning_tree_state_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.spanning_tree_state(int_type=self.phys_int_type,
                                               name='9/0', enabled=True)

    def test_spanning_tree_state_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.spanning_tree_state(int_type='port_channel',
                                               name='9/0', enabled=True)

    def test_tag_native_vlan_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.tag_native_vlan(int_type='hodor', name='9')

    def test_tag_native_vlan_phys_int_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.tag_native_vlan(int_type=self.phys_int_type,
                                           name='9/0')

    def test_tag_native_vlan_port_channel_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.tag_native_vlan(int_type='port_channel', name='9/0')

    def test_tag_native_vlan_bool_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.tag_native_vlan(int_type='port_channel', name='9',
                                           enabled='hodor')

    def test_switchport_pvlan_mapping_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.switchport_pvlan_mapping(int_type='port-channel',
                                                    name='9',
                                                    pri_vlan=self.vlan_id,
                                                    sec_vlan=self.sec_vlan)

    def test_switchport_pvlan_mapping_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            int_type = self.phys_int_type
            self.interface.switchport_pvlan_mapping(int_type=int_type,
                                                    name='9/0',
                                                    pri_vlan=self.vlan_id,
                                                    sec_vlan=self.sec_vlan)

    def test_switchport_pvlan_mapping_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.switchport_pvlan_mapping(int_type='port_channel',
                                                    name='9/0',
                                                    pri_vlan=self.vlan_id,
                                                    sec_vlan=self.sec_vlan)

    def test_switchport_pvlan_mapping_pri_vlan_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.switchport_pvlan_mapping(int_type='port_channel',
                                                    name='9', pri_vlan='9000',
                                                    sec_vlan=self.sec_vlan)

    def test_switchport_pvlan_mapping_sec_vlan_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.switchport_pvlan_mapping(int_type='port_channel',
                                                    name='9', sec_vlan='9000',
                                                    pri_vlan=self.vlan_id)

    def test_mtu_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.mtu(int_type='port-channel', name='9', mtu='1522')

    def test_mtu_mtu_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.mtu(int_type='port_channel', name='9', mtu='9217')

    def test_mtu_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.mtu(int_type=self.phys_int_type, name='9/0',
                               mtu='1522')

    def test_mtu_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.mtu(int_type='port_channel', name='9/0', mtu='1522')

    def test_fabric_isl_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.fabric_isl(int_type=self.phys_int_type,
                                      name=self.phys_name)

    def test_fabric_isl_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.fabric_isl(int_type='tengigabitethernet',
                                      name='2/0')

    def test_fabric_isl_bool_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.fabric_isl(int_type='tengigabitethernet',
                                      name='2/0/0', enabled='hodor')

    def test_fabric_trunk_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.fabric_trunk(int_type=self.phys_int_type,
                                        name=self.phys_name)

    def test_fabric_trunk_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.fabric_trunk(int_type='tengigabitethernet',
                                        name='2/0')

    def test_fabric_trunk_bool_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.fabric_trunk(int_type='tengigabitethernet',
                                        name='2/0/0',
                                        enabled='hodor')

    def test_v6_nd_suppress_ra_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.v6_nd_suppress_ra(int_type='port_channel', name='5')

    def test_v6_nd_suppress_ra_ve_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.v6_nd_suppress_ra(int_type='ve', name='12345')

    def test_v6_nd_suppress_ra_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.v6_nd_suppress_ra(int_type=self.phys_int_type,
                                             name='2/0')

    def test_vrrp_vip_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.vrrp_vip(int_type='port-channel', name='5',
                                    vrid='1', vip='10.0.0.1')

    def test_vrrp_vip_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.vrrp_vip(int_type=self.phys_int_type, name='2/0',
                                    vrid='1', vip='10.0.0.1')

    def test_vrrp_vip_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.vrrp_vip(int_type='port_channel', name='2/0',
                                    vrid='1', vip='10.0.0.1')

    def test_vrrp_priority_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.vrrp_priority(int_type='port-channel', name='5',
                                         vrid='1', priority='75',
                                         ip_version='4')

    def test_vrrp_priority_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.vrrp_priority(int_type=self.phys_int_type,
                                         name='2/0', vrid='1', priority='75',
                                         ip_version='4')

    def test_vrrp_priority_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.vrrp_priority(int_type='port_channel', name='2/0',
                                         vrid='1', priority='75',
                                         ip_version='4')

    def test_proxy_arp_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.proxy_arp(int_type='port-channel', name='2')

    def test_proxy_arp_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.proxy_arp(int_type=self.phys_int_type, name='2/0')

    def test_proxy_arp_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.proxy_arp(int_type='port_channel', name='2/0')

    def test_proxy_arp_bool_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.proxy_arp(int_type='port_channel', name='2',
                                     enabled='hodor')

    def test_port_channel_minimum_links_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.port_channel_minimum_links(name=self.phys_name,
                                                      minimum_links='3')

    def test_channel_group_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.channel_group(int_type='port_channel', name='5',
                                         channel_type='standard', port_int='7',
                                         mode='active')

    def test_channel_group_channel_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.channel_group(int_type=self.phys_int_type,
                                         name=self.phys_name, mode='active',
                                         channel_type='hodor', port_int='7')

    def test_channel_group_mode_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.channel_group(int_type=self.phys_int_type,
                                         name=self.phys_name, mode='hodor',
                                         channel_type='standard', port_int='7')

    def test_channel_group_port_int_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.channel_group(int_type=self.phys_int_type,
                                         name=self.phys_name, mode='active',
                                         channel_type='standard',
                                         port_int='1234')

    def test_channel_group_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.channel_group(int_type=self.phys_int_type,
                                         name='2/0', mode='active',
                                         channel_type='standard', port_int='7')

    def test_channel_group_delete(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<channel-group operation="delete"><mode>active</mode>'\
                   '</channel-group></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.channel_group(int_type=self.phys_int_type,
                                              name=self.phys_name,
                                              mode='active', port_int='5',
                                              channel_type='brocade',
                                              delete=True)
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_port_channel_vlag_ignore_split_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.port_channel_vlag_ignore_split(name='2/0',
                                                          enabled=True)

    def test_trunk_mode_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.trunk_mode(int_type='port-channel', name='5',
                                      mode='trunk')

    def test_trunk_mode_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.trunk_mode(int_type=self.phys_int_type,
                                      name='2/0', mode='trunk')

    def test_trunk_mode_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.trunk_mode(int_type='port_channel', name='2/0',
                                      mode='trunk')

    def test_trunk_mode_mode_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.trunk_mode(int_type=self.phys_int_type,
                                      name=self.phys_name, mode='hodor')

    def test_transport_service_vlan_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.transport_service(vlan='9000', service_id='1')

    def test_lacp_timeout_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.lacp_timeout(int_type='port_channel',
                                        name='225/0/1', timeout='long')

    def test_lacp_timeout_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.lacp_timeout(int_type=self.phys_int_type,
                                        name='5',
                                        timeout='5')

    def test_lacp_timeout_timeout_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.lacp_timeout(int_type=self.phys_int_type,
                                        name=self.phys_name, timeout='5')

    def test_switchport_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.switchport(int_type='port-channel',
                                      name=self.phys_name)

    def test_switchport_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.switchport(int_type=self.phys_int_type, name='2/0')

    def test_switchport_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.switchport(int_type='port_channel', name='2/0')

    def test_acc_vlan_int_type_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.acc_vlan(int_type='port-channel', name='5',
                                    vlan=self.vlan_id)

    def test_acc_vlan_vlan_value_error(self):
        with self.assertRaises(InvalidVlanId):
            self.interface.acc_vlan(int_type=self.phys_int_type,
                                    name=self.phys_name, vlan='9000')

    def test_acc_vlan_phys_int_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.acc_vlan(int_type=self.phys_int_type,
                                    name='2/0', vlan=self.vlan_id)

    def test_acc_vlan_port_channel_name_value_error(self):
        with self.assertRaises(ValueError):
            self.interface.acc_vlan(int_type='port_channel', name='2/0',
                                    vlan=self.vlan_id)

    def test_port_channel_vlag_ignore_split_enabled_default_value(self):
        expected = '<config><interface xmlns="{0}"><port-channel>'\
                   '<name>5</name><vlag><ignore-split /></vlag>'\
                   '</port-channel></interface>'\
                   '</config>'.format(self.namespace)
        result = self.interface.port_channel_vlag_ignore_split(name='5')
        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_mtu_too_low(self):
        with self.assertRaises(ValueError):
            self.interface.mtu(int_type=self.phys_int_type, mtu='1521',
                               name=self.phys_name)

    def test_mtu_too_high(self):
        with self.assertRaises(ValueError):
            self.interface.mtu(int_type=self.phys_int_type, mtu='9217',
                               name=self.phys_name)

    def test_mtu_floor(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<mtu>1522</mtu></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.mtu(int_type=self.phys_int_type, mtu='1522',
                                    name=self.phys_name)

        result = ET.tostring(result)
        self.assertEquals(expected, result)

    def test_mtu_ceiling(self):
        expected = '<config><interface xmlns="{0}"><{1}><name>{2}</name>'\
                   '<mtu>9216</mtu></{1}></interface>'\
                   '</config>'.format(self.namespace, self.phys_int_type,
                                      self.phys_name)
        result = self.interface.mtu(int_type=self.phys_int_type, mtu='9216',
                                    name=self.phys_name)
        result = ET.tostring(result)
        self.assertEquals(expected, result)



#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_cee_map(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def cee_map_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name = ET.SubElement(cee_map, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_precedence(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        precedence = ET.SubElement(cee_map, "precedence")
        precedence.text = kwargs.pop('precedence')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_group_table_PGID(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_group_table = ET.SubElement(cee_map, "priority-group-table")
        PGID = ET.SubElement(priority_group_table, "PGID")
        PGID.text = kwargs.pop('PGID')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_group_table_weight(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_group_table = ET.SubElement(cee_map, "priority-group-table")
        PGID_key = ET.SubElement(priority_group_table, "PGID")
        PGID_key.text = kwargs.pop('PGID')
        weight = ET.SubElement(priority_group_table, "weight")
        weight.text = kwargs.pop('weight')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_group_table_pfc(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_group_table = ET.SubElement(cee_map, "priority-group-table")
        PGID_key = ET.SubElement(priority_group_table, "PGID")
        PGID_key.text = kwargs.pop('PGID')
        pfc = ET.SubElement(priority_group_table, "pfc")
        pfc.text = kwargs.pop('pfc')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos0_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos0_pgid = ET.SubElement(priority_table, "map-cos0-pgid")
        map_cos0_pgid.text = kwargs.pop('map_cos0_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos1_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos1_pgid = ET.SubElement(priority_table, "map-cos1-pgid")
        map_cos1_pgid.text = kwargs.pop('map_cos1_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos2_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos2_pgid = ET.SubElement(priority_table, "map-cos2-pgid")
        map_cos2_pgid.text = kwargs.pop('map_cos2_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos3_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos3_pgid = ET.SubElement(priority_table, "map-cos3-pgid")
        map_cos3_pgid.text = kwargs.pop('map_cos3_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos4_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos4_pgid = ET.SubElement(priority_table, "map-cos4-pgid")
        map_cos4_pgid.text = kwargs.pop('map_cos4_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos5_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos5_pgid = ET.SubElement(priority_table, "map-cos5-pgid")
        map_cos5_pgid.text = kwargs.pop('map_cos5_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos6_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos6_pgid = ET.SubElement(priority_table, "map-cos6-pgid")
        map_cos6_pgid.text = kwargs.pop('map_cos6_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos7_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos7_pgid = ET.SubElement(priority_table, "map-cos7-pgid")
        map_cos7_pgid.text = kwargs.pop('map_cos7_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_remap_fabric_priority_fabric_remapped_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        remap = ET.SubElement(cee_map, "remap")
        fabric_priority = ET.SubElement(remap, "fabric-priority")
        fabric_remapped_priority = ET.SubElement(fabric_priority, "fabric-remapped-priority")
        fabric_remapped_priority.text = kwargs.pop('fabric_remapped_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_remap_lossless_priority_lossless_remapped_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        remap = ET.SubElement(cee_map, "remap")
        lossless_priority = ET.SubElement(remap, "lossless-priority")
        lossless_remapped_priority = ET.SubElement(lossless_priority, "lossless-remapped-priority")
        lossless_remapped_priority.text = kwargs.pop('lossless_remapped_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name = ET.SubElement(cee_map, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_precedence(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        precedence = ET.SubElement(cee_map, "precedence")
        precedence.text = kwargs.pop('precedence')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_group_table_PGID(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_group_table = ET.SubElement(cee_map, "priority-group-table")
        PGID = ET.SubElement(priority_group_table, "PGID")
        PGID.text = kwargs.pop('PGID')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_group_table_weight(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_group_table = ET.SubElement(cee_map, "priority-group-table")
        PGID_key = ET.SubElement(priority_group_table, "PGID")
        PGID_key.text = kwargs.pop('PGID')
        weight = ET.SubElement(priority_group_table, "weight")
        weight.text = kwargs.pop('weight')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_group_table_pfc(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_group_table = ET.SubElement(cee_map, "priority-group-table")
        PGID_key = ET.SubElement(priority_group_table, "PGID")
        PGID_key.text = kwargs.pop('PGID')
        pfc = ET.SubElement(priority_group_table, "pfc")
        pfc.text = kwargs.pop('pfc')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos0_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos0_pgid = ET.SubElement(priority_table, "map-cos0-pgid")
        map_cos0_pgid.text = kwargs.pop('map_cos0_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos1_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos1_pgid = ET.SubElement(priority_table, "map-cos1-pgid")
        map_cos1_pgid.text = kwargs.pop('map_cos1_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos2_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos2_pgid = ET.SubElement(priority_table, "map-cos2-pgid")
        map_cos2_pgid.text = kwargs.pop('map_cos2_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos3_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos3_pgid = ET.SubElement(priority_table, "map-cos3-pgid")
        map_cos3_pgid.text = kwargs.pop('map_cos3_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos4_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos4_pgid = ET.SubElement(priority_table, "map-cos4-pgid")
        map_cos4_pgid.text = kwargs.pop('map_cos4_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos5_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos5_pgid = ET.SubElement(priority_table, "map-cos5-pgid")
        map_cos5_pgid.text = kwargs.pop('map_cos5_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos6_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos6_pgid = ET.SubElement(priority_table, "map-cos6-pgid")
        map_cos6_pgid.text = kwargs.pop('map_cos6_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_priority_table_map_cos7_pgid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        priority_table = ET.SubElement(cee_map, "priority-table")
        map_cos7_pgid = ET.SubElement(priority_table, "map-cos7-pgid")
        map_cos7_pgid.text = kwargs.pop('map_cos7_pgid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_remap_fabric_priority_fabric_remapped_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        remap = ET.SubElement(cee_map, "remap")
        fabric_priority = ET.SubElement(remap, "fabric-priority")
        fabric_remapped_priority = ET.SubElement(fabric_priority, "fabric-remapped-priority")
        fabric_remapped_priority.text = kwargs.pop('fabric_remapped_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def cee_map_remap_lossless_priority_lossless_remapped_priority(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        cee_map = ET.SubElement(config, "cee-map", xmlns="urn:brocade.com:mgmt:brocade-cee-map")
        name_key = ET.SubElement(cee_map, "name")
        name_key.text = kwargs.pop('name')
        remap = ET.SubElement(cee_map, "remap")
        lossless_priority = ET.SubElement(remap, "lossless-priority")
        lossless_remapped_priority = ET.SubElement(lossless_priority, "lossless-remapped-priority")
        lossless_remapped_priority.text = kwargs.pop('lossless_remapped_priority')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from ipaddress import ip_interface
import xml.etree.ElementTree as ET
from pynos.versions.base.yang.brocade_rbridge import brocade_rbridge
import pynos.utilities


class BGP(object):
    """
    The BGP class holds all relevent methods and attributes for the BGP
    capabilities of the NOS device.

    Attributes:
        None
    """
    def __init__(self, callback):
        """
        BGP object init.

        Args:
            callback: Callback function that will be called for each action.

        Returns:
            BGP Object

        Raises:
            None
        """
        self._callback = callback
        self._rbridge = brocade_rbridge(callback=pynos.utilities.return_xml)

    @property
    def enabled(self):
        """bool: ``True`` if BGP is enabled; ``False`` if BGP is disabled.
        """
        namespace = 'urn:ietf:params:xml:ns:netconf:base:1.0'
        bgp_filter = 'rbridge-id/router/bgp'
        bgp_config = ET.Element('get-config', xmlns="%s" % namespace)
        source = ET.SubElement(bgp_config, 'source')
        ET.SubElement(source, 'running')
        ET.SubElement(bgp_config, 'filter',
                      type="xpath", select="%s" % bgp_filter)
        bgp_config = self._callback(bgp_config, handler='get')
        namespace = 'urn:brocade.com:mgmt:brocade-bgp'
        enabled = bgp_config.find('.//*{%s}bgp' % namespace)
        if enabled is not None:
            return True
        return False

    def local_asn(self, **kwargs):
        """Set BGP local ASN.

        Args:
            local_as (str): Local ASN of NOS deice.
            vrf (str): The VRF for this BGP process.
            rbridge_id (str): The rbridge ID of the device on which BGP will be
                configured in a VCS fabric.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `local_as` is not specified.

        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.bgp.local_asn(local_as='65535',
            ...     rbridge_id='225')
            ...     dev.bgp.local_asn() # doctest: +IGNORE_EXCEPTION_DETAIL
            Traceback (most recent call last):
            KeyError
        """
        vrf = kwargs.pop('vrf', 'default')
        local_as = kwargs.pop('local_as')
        rbridge_id = kwargs.pop('rbridge_id', '1')
        callback = kwargs.pop('callback', self._callback)
        bgp_args = dict(vrf_name=vrf, rbridge_id=rbridge_id)
        config = self._rbridge.rbridge_id_router_bgp_vrf_name(**bgp_args)
        callback(config)
        local_as_args = dict(vrf_name=vrf,
                             local_as=local_as,
                             rbridge_id=rbridge_id)
        local_as = getattr(self._rbridge,
                           'rbridge_id_router_bgp_router_bgp_cmds_holder_'
                           'router_bgp_attributes_local_as')
        config = local_as(**local_as_args)
        return callback(config)

    def remove_bgp(self, **kwargs):
        """Remove BGP process completely.

        Args:
            vrf (str): The VRF for this BGP process.
            rbridge_id (str): The rbridge ID of the device on which BGP will be
                configured in a VCS fabric.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            None

        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.bgp.local_asn(local_as='65535',
            ...     rbridge_id='225')
            ...     output = dev.bgp.remove_bgp(rbridge_id='225')
        """
        vrf = kwargs.pop('vrf', 'default')
        rbridge_id = kwargs.pop('rbridge_id', '1')
        callback = kwargs.pop('callback', self._callback)
        bgp_args = dict(vrf_name=vrf, rbridge_id=rbridge_id)
        config = self._rbridge.rbridge_id_router_bgp_vrf_name(**bgp_args)
        config.find('.//*bgp').set('operation', 'delete')

        return callback(config)

    def neighbor(self, **kwargs):
        """Add BGP neighbor.

        Args:
            ip_addr (str): IP Address of BGP neighbor.
            remote_as (str): Remote ASN of BGP neighbor.
            vrf (str): The VRF for this BGP process.
            rbridge_id (str): The rbridge ID of the device on which BGP will be
                configured in a VCS fabric.
            delete (bool): Deletes the neighbor if `delete` is ``True``.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `remote_as` or `ip_addr` is not specified.

        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.bgp.local_asn(local_as='65535',
            ...     rbridge_id='225')
            ...     output = dev.bgp.neighbor(ip_addr='10.10.10.10',
            ...     remote_as='65535', rbridge_id='225')
            ...     output = dev.bgp.neighbor(remote_as='65535',
            ...     rbridge_id='225',
            ...     ip_addr='2001:4818:f000:1ab:cafe:beef:1000:1')
            ...     output = dev.bgp.neighbor(ip_addr='10.10.10.10',
            ...     delete=True, rbridge_id='225')
            ...     output = dev.bgp.neighbor(delete=True, rbridge_id='225',
            ...     ip_addr='2001:4818:f000:1ab:cafe:beef:1000:1')
            ...     dev.bgp.neighbor() # doctest: +IGNORE_EXCEPTION_DETAIL
            Traceback (most recent call last):
            KeyError
        """
        ip_addr = kwargs.pop('ip_addr')
        remote_as = kwargs.pop('remote_as', None)
        vrf = kwargs.pop('vrf', 'default')
        rbridge_id = kwargs.pop('rbridge_id', '1')
        delete = kwargs.pop('delete', False)
        callback = kwargs.pop('callback', self._callback)
        ip_addr = ip_interface(unicode(ip_addr))

        if not delete and remote_as is None:
            raise ValueError('When configuring a neighbor, you must specify '
                             'its remote-as.')

        neighbor_args = dict(router_bgp_neighbor_address=str(ip_addr.ip),
                             remote_as=remote_as,
                             vrf_name=vrf,
                             rbridge_id=rbridge_id)

        if ip_addr.version == 4:
            neighbor = getattr(self._rbridge,
                               'rbridge_id_router_bgp_router_bgp_cmds_holder_'
                               'router_bgp_attributes_neighbor_ips_'
                               'neighbor_addr_remote_as')
            ip_addr_path = './/*neighbor-addr'
        else:
            neighbor_args['router_bgp_neighbor_ipv6_address'] = str(ip_addr.ip)
            neighbor = getattr(self._rbridge,
                               'rbridge_id_router_bgp_router_bgp_cmds_holder_'
                               'router_bgp_attributes_neighbor_ipv6s_neighbor_'
                               'ipv6_addr_remote_as')
            ip_addr_path = './/*neighbor-ipv6-addr'

        config = neighbor(**neighbor_args)

        if delete:
            neighbor = config.find(ip_addr_path)
            neighbor.set('operation', 'delete')
            neighbor.remove(neighbor.find('remote-as'))
            if ip_addr.version == 6:
                activate_args = dict(vrf_name=vrf, rbridge_id=rbridge_id,
                                     af_ipv6_neighbor_address=str(ip_addr.ip))
                activate_neighbor = getattr(self._rbridge,
                                            'rbridge_id_router_bgp_router_bgp_'
                                            'cmds_holder_address_family_ipv6_'
                                            'ipv6_unicast_af_ipv6_neighbor_'
                                            'address_holder_af_ipv6_'
                                            'neighbor_address_activate')
                deactivate = activate_neighbor(**activate_args)
                deactivate.find('.//*af-ipv6-neighbor-'
                                'address').set('operation', 'delete')
                callback(deactivate)
        else:
            if ip_addr.version == 6:
                callback(config)
                activate_args = dict(vrf_name=vrf, rbridge_id=rbridge_id,
                                     af_ipv6_neighbor_address=str(ip_addr.ip))
                activate_neighbor = getattr(self._rbridge,
                                            'rbridge_id_router_bgp_router_bgp_'
                                            'cmds_holder_address_family_ipv6_'
                                            'ipv6_unicast_af_ipv6_neighbor_'
                                            'address_holder_af_ipv6_'
                                            'neighbor_address_activate')
                config = activate_neighbor(**activate_args)
        return callback(config)



#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_dai(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def arp_access_list_acl_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name = ET.SubElement(access_list, "acl-name")
        acl_name.text = kwargs.pop('acl_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_permit_permit_list_ip_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name_key = ET.SubElement(access_list, "acl-name")
        acl_name_key.text = kwargs.pop('acl_name')
        permit = ET.SubElement(access_list, "permit")
        permit_list = ET.SubElement(permit, "permit-list")
        host_ip_key = ET.SubElement(permit_list, "host-ip")
        host_ip_key.text = kwargs.pop('host_ip')
        mac_type_key = ET.SubElement(permit_list, "mac-type")
        mac_type_key.text = kwargs.pop('mac_type')
        host_mac_key = ET.SubElement(permit_list, "host-mac")
        host_mac_key.text = kwargs.pop('host_mac')
        ip_type = ET.SubElement(permit_list, "ip-type")
        ip_type.text = kwargs.pop('ip_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_permit_permit_list_host_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name_key = ET.SubElement(access_list, "acl-name")
        acl_name_key.text = kwargs.pop('acl_name')
        permit = ET.SubElement(access_list, "permit")
        permit_list = ET.SubElement(permit, "permit-list")
        ip_type_key = ET.SubElement(permit_list, "ip-type")
        ip_type_key.text = kwargs.pop('ip_type')
        mac_type_key = ET.SubElement(permit_list, "mac-type")
        mac_type_key.text = kwargs.pop('mac_type')
        host_mac_key = ET.SubElement(permit_list, "host-mac")
        host_mac_key.text = kwargs.pop('host_mac')
        host_ip = ET.SubElement(permit_list, "host-ip")
        host_ip.text = kwargs.pop('host_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_permit_permit_list_mac_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name_key = ET.SubElement(access_list, "acl-name")
        acl_name_key.text = kwargs.pop('acl_name')
        permit = ET.SubElement(access_list, "permit")
        permit_list = ET.SubElement(permit, "permit-list")
        ip_type_key = ET.SubElement(permit_list, "ip-type")
        ip_type_key.text = kwargs.pop('ip_type')
        host_ip_key = ET.SubElement(permit_list, "host-ip")
        host_ip_key.text = kwargs.pop('host_ip')
        host_mac_key = ET.SubElement(permit_list, "host-mac")
        host_mac_key.text = kwargs.pop('host_mac')
        mac_type = ET.SubElement(permit_list, "mac-type")
        mac_type.text = kwargs.pop('mac_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_permit_permit_list_host_mac(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name_key = ET.SubElement(access_list, "acl-name")
        acl_name_key.text = kwargs.pop('acl_name')
        permit = ET.SubElement(access_list, "permit")
        permit_list = ET.SubElement(permit, "permit-list")
        ip_type_key = ET.SubElement(permit_list, "ip-type")
        ip_type_key.text = kwargs.pop('ip_type')
        host_ip_key = ET.SubElement(permit_list, "host-ip")
        host_ip_key.text = kwargs.pop('host_ip')
        mac_type_key = ET.SubElement(permit_list, "mac-type")
        mac_type_key.text = kwargs.pop('mac_type')
        host_mac = ET.SubElement(permit_list, "host-mac")
        host_mac.text = kwargs.pop('host_mac')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_permit_permit_list_log(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name_key = ET.SubElement(access_list, "acl-name")
        acl_name_key.text = kwargs.pop('acl_name')
        permit = ET.SubElement(access_list, "permit")
        permit_list = ET.SubElement(permit, "permit-list")
        ip_type_key = ET.SubElement(permit_list, "ip-type")
        ip_type_key.text = kwargs.pop('ip_type')
        host_ip_key = ET.SubElement(permit_list, "host-ip")
        host_ip_key.text = kwargs.pop('host_ip')
        mac_type_key = ET.SubElement(permit_list, "mac-type")
        mac_type_key.text = kwargs.pop('mac_type')
        host_mac_key = ET.SubElement(permit_list, "host-mac")
        host_mac_key.text = kwargs.pop('host_mac')
        log = ET.SubElement(permit_list, "log")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_acl_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name = ET.SubElement(access_list, "acl-name")
        acl_name.text = kwargs.pop('acl_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_permit_permit_list_ip_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name_key = ET.SubElement(access_list, "acl-name")
        acl_name_key.text = kwargs.pop('acl_name')
        permit = ET.SubElement(access_list, "permit")
        permit_list = ET.SubElement(permit, "permit-list")
        host_ip_key = ET.SubElement(permit_list, "host-ip")
        host_ip_key.text = kwargs.pop('host_ip')
        mac_type_key = ET.SubElement(permit_list, "mac-type")
        mac_type_key.text = kwargs.pop('mac_type')
        host_mac_key = ET.SubElement(permit_list, "host-mac")
        host_mac_key.text = kwargs.pop('host_mac')
        ip_type = ET.SubElement(permit_list, "ip-type")
        ip_type.text = kwargs.pop('ip_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_permit_permit_list_host_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name_key = ET.SubElement(access_list, "acl-name")
        acl_name_key.text = kwargs.pop('acl_name')
        permit = ET.SubElement(access_list, "permit")
        permit_list = ET.SubElement(permit, "permit-list")
        ip_type_key = ET.SubElement(permit_list, "ip-type")
        ip_type_key.text = kwargs.pop('ip_type')
        mac_type_key = ET.SubElement(permit_list, "mac-type")
        mac_type_key.text = kwargs.pop('mac_type')
        host_mac_key = ET.SubElement(permit_list, "host-mac")
        host_mac_key.text = kwargs.pop('host_mac')
        host_ip = ET.SubElement(permit_list, "host-ip")
        host_ip.text = kwargs.pop('host_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_permit_permit_list_mac_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name_key = ET.SubElement(access_list, "acl-name")
        acl_name_key.text = kwargs.pop('acl_name')
        permit = ET.SubElement(access_list, "permit")
        permit_list = ET.SubElement(permit, "permit-list")
        ip_type_key = ET.SubElement(permit_list, "ip-type")
        ip_type_key.text = kwargs.pop('ip_type')
        host_ip_key = ET.SubElement(permit_list, "host-ip")
        host_ip_key.text = kwargs.pop('host_ip')
        host_mac_key = ET.SubElement(permit_list, "host-mac")
        host_mac_key.text = kwargs.pop('host_mac')
        mac_type = ET.SubElement(permit_list, "mac-type")
        mac_type.text = kwargs.pop('mac_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_permit_permit_list_host_mac(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name_key = ET.SubElement(access_list, "acl-name")
        acl_name_key.text = kwargs.pop('acl_name')
        permit = ET.SubElement(access_list, "permit")
        permit_list = ET.SubElement(permit, "permit-list")
        ip_type_key = ET.SubElement(permit_list, "ip-type")
        ip_type_key.text = kwargs.pop('ip_type')
        host_ip_key = ET.SubElement(permit_list, "host-ip")
        host_ip_key.text = kwargs.pop('host_ip')
        mac_type_key = ET.SubElement(permit_list, "mac-type")
        mac_type_key.text = kwargs.pop('mac_type')
        host_mac = ET.SubElement(permit_list, "host-mac")
        host_mac.text = kwargs.pop('host_mac')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def arp_access_list_permit_permit_list_log(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        arp = ET.SubElement(config, "arp", xmlns="urn:brocade.com:mgmt:brocade-dai")
        access_list = ET.SubElement(arp, "access-list")
        acl_name_key = ET.SubElement(access_list, "acl-name")
        acl_name_key.text = kwargs.pop('acl_name')
        permit = ET.SubElement(access_list, "permit")
        permit_list = ET.SubElement(permit, "permit-list")
        ip_type_key = ET.SubElement(permit_list, "ip-type")
        ip_type_key.text = kwargs.pop('ip_type')
        host_ip_key = ET.SubElement(permit_list, "host-ip")
        host_ip_key.text = kwargs.pop('host_ip')
        mac_type_key = ET.SubElement(permit_list, "mac-type")
        mac_type_key.text = kwargs.pop('mac_type')
        host_mac_key = ET.SubElement(permit_list, "host-mac")
        host_mac_key.text = kwargs.pop('host_mac')
        log = ET.SubElement(permit_list, "log")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_entity(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def get_contained_in_ID_output_contained_in_ID(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_contained_in_ID = ET.Element("get_contained_in_ID")
        config = get_contained_in_ID
        output = ET.SubElement(get_contained_in_ID, "output")
        contained_in_ID = ET.SubElement(output, "contained-in-ID")
        contained_in_ID.text = kwargs.pop('contained_in_ID')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_contained_in_ID_output_contained_in_ID(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_contained_in_ID = ET.Element("get_contained_in_ID")
        config = get_contained_in_ID
        output = ET.SubElement(get_contained_in_ID, "output")
        contained_in_ID = ET.SubElement(output, "contained-in-ID")
        contained_in_ID.text = kwargs.pop('contained_in_ID')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_license(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def dpod_port_id_port_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        dpod = ET.SubElement(config, "dpod", xmlns="urn:brocade.com:mgmt:brocade-license")
        port_id = ET.SubElement(dpod, "port-id")
        port_id = ET.SubElement(port_id, "port-id")
        port_id.text = kwargs.pop('port_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def dpod_port_id_operation(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        dpod = ET.SubElement(config, "dpod", xmlns="urn:brocade.com:mgmt:brocade-license")
        port_id = ET.SubElement(dpod, "port-id")
        port_id_key = ET.SubElement(port_id, "port-id")
        port_id_key.text = kwargs.pop('port_id')
        operation = ET.SubElement(port_id, "operation")
        operation.text = kwargs.pop('operation')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def dpod_port_id_port_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        dpod = ET.SubElement(config, "dpod", xmlns="urn:brocade.com:mgmt:brocade-license")
        port_id = ET.SubElement(dpod, "port-id")
        port_id = ET.SubElement(port_id, "port-id")
        port_id.text = kwargs.pop('port_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def dpod_port_id_operation(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        dpod = ET.SubElement(config, "dpod", xmlns="urn:brocade.com:mgmt:brocade-license")
        port_id = ET.SubElement(dpod, "port-id")
        port_id_key = ET.SubElement(port_id, "port-id")
        port_id_key.text = kwargs.pop('port_id')
        operation = ET.SubElement(port_id, "operation")
        operation.text = kwargs.pop('operation')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        